# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [
      ../../modules

      # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Bootloader.
  boot.loader = {
    grub = {
      enable = true;
      device = "/dev/vda";
      efiSupport = false;
      useOSProber = true;
    };
  };

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.florian = {
    isNormalUser = true;
    initialPassword = "test";
    description = "florian";
    extraGroups = [ "networkmanager" "wheel" ];
  };
  home-manager.users.florian = {
    home = {
      username = "florian";
      homeDirectory = "/home/florian";

      stateVersion = "24.05";
    };

    programs.home-manager.enable = true;
    nix.settings.experimental-features = [ "nix-command" "flakes" ];
  };

  # Configure for testing in vm
  virtualisation.vmVariant = {
    # following configuration is added only when building VM with build-vm
    virtualisation = {
      memorySize = 8192; # Use 8192MiB memory.
      cores = 8;         
    };
  };

  networking.hostName = "nixos-vm"; # Define your hostname.
}
